pub unsafe extern "system" fn SQLDescribeParam(
statement_handle: *mut Stmt,
parameter_number: u16,
data_type_ptr: *mut SqlDataType,
parameter_size_ptr: *mut u64,
decimal_digits_ptr: *mut i16,
nullable_ptr: *mut i16,
) -> SQLRETURNExpand description
Returns the description of a parameter marker associated with a prepared SQL statement. This information is also available in the fields of the IPD.
Returns
SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_STILL_EXECUTING, SQL_ERROR, or
SQL_INVALID_HANDLE.