SQLFreeStmt

Function SQLFreeStmt 

pub unsafe extern "system" fn SQLFreeStmt(
    hstmt: *mut Stmt,
    option: FreeStmtOption,
) -> SQLRETURN
Stops processing associated with a specific statement, closes any open cursors associated with the statement, discards pending results, or, optionally, frees all resources associated with the statement handle.

Returns

SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE.