pub unsafe extern "system" fn SQLGetDiagRec(
handle_type: HandleType,
handle: *mut Obj,
RecNumber: i16,
state: *mut u8,
native_error_ptr: *mut i32,
message_text: *mut u8,
buffer_length: i16,
text_length_ptr: *mut i16,
) -> SQLRETURNExpand description
Return the current values of multiple fields of a diagnostic record that contains eror, warning, and status information.
Returns
SQL_SUCCESS, SQL_SUCCESS_WITH_INFO, SQL_ERROR, or SQL_INVALID_HANDLE