[−][src]Trait odbc_iter::TryFromValueRow
This traits allow for conversion of ValueRow type used internally by ResultSet iterator to any
other type returned as Item that implements it.
This trait is implemented for Rust tuple type enabling conversion of rows to tuples of types implementing TryFromValue.
Also this trait implementation allows to convert single column rows to types implementing TryFromValue.
This trait can be implemented for custom objects. This will enable them to be queried directly from database as Item of ResultSet iterator.
Associated Types
Loading content...Required methods
fn try_from_value_row(values: ValueRow) -> Result<Self, Self::Error>
Convert from ValueRow to other type of value representing table row.
Implementations on Foreign Types
impl TryFromValueRow for ()[src]
Unit can be used to signal that no rows of data should be produced.
type Error = ValueRowConvertError
fn try_from_value_row(_values: ValueRow) -> Result<Self, Self::Error>[src]
impl<A: TryFromValue> TryFromValueRow for (A,)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(values: ValueRow) -> Result<(A,), Self::Error>[src]
impl<A: TryFromValue, B: TryFromValue> TryFromValueRow for (A, B)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(values: ValueRow) -> Result<(A, B), Self::Error>[src]
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue> TryFromValueRow for (A, B, C)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(values: ValueRow) -> Result<(A, B, C), Self::Error>[src]
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue> TryFromValueRow for (A, B, C, D)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(values: ValueRow) -> Result<(A, B, C, D), Self::Error>[src]
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue> TryFromValueRow for (A, B, C, D, E)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(values: ValueRow) -> Result<(A, B, C, D, E), Self::Error>[src]
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue> TryFromValueRow for (A, B, C, D, E, F)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue, H: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G, H)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue, H: TryFromValue, I: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G, H, I)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue, H: TryFromValue, I: TryFromValue, J: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G, H, I, J)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue, H: TryFromValue, I: TryFromValue, J: TryFromValue, K: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G, H, I, J, K)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J, K), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J, K), Self::Error>
impl<A: TryFromValue, B: TryFromValue, C: TryFromValue, D: TryFromValue, E: TryFromValue, F: TryFromValue, G: TryFromValue, H: TryFromValue, I: TryFromValue, J: TryFromValue, K: TryFromValue, L: TryFromValue> TryFromValueRow for (A, B, C, D, E, F, G, H, I, J, K, L)[src]
type Error = ValueRowConvertTupleError
fn try_from_value_row(
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J, K, L), Self::Error>[src]
values: ValueRow
) -> Result<(A, B, C, D, E, F, G, H, I, J, K, L), Self::Error>
Implementors
impl TryFromValueRow for ValueRow[src]
Allow to retrieve unconverted ValueRow as item of ResultSet iterator.
type Error = Infallible
fn try_from_value_row(values: ValueRow) -> Result<Self, Self::Error>[src]
impl<T> TryFromValueRow for T where
T: TryFromValue, [src]
T: TryFromValue,
Convert row with single column to any type implementing TryFromValue.