Executed

Type Alias Executed 

pub type Executed = Allocated;
Statement state used to represent a statement with a result set cursor. A statement is most likely to enter this state after a SELECT query.

Aliased Type

pub enum Executed {}